=========
Changelog
=========

Unreleased
==========

2018/10/23 0.1.0
================

- *[FEATURE]* Add Base64 template filters (``b64encode``, ``b64decode``).

- *[FEATURE]* Add support for the `HCL <https://github.com/hashicorp/hcl>`_
  file format as input file.

- *[FEATURE]* Initial feature set with YAML and JSON file format as input file.
